<?php

class Cadastro_Model extends CI_Model {

    function __construct() {
        parent::__construct();
    }

    function verificaAluno() {
        
        $this->db->select('a.id_aluno, a.instituicao, a.id_cliente, b.nome, b.saldo, b.bonificacao, b.id_negocio, b.nome, b.saldo_anterior, b.nome_negocio');
        $this->db->where ('a.id_aluno', $_SESSION['logado']['id']);
        $this->db->where ('a.id_cliente = b.id_cliente');
        $this->db->order_by("id", "desc");
        $query = $this->db->get('amn_aluno a, amn_cliente b')->row_array();

        return $query;
    }
    
    public function getAlunoPorID() {
        $this->db->where("id_aluno", $_SESSION['amazonia']);
        $query = $this->db->get('aluno');

        if ($query->num_rows() > 0) {
            return $query->row_array();
        } else {
            return FALSE;
        }
    }
    public function obtemTermo() {
        
        $this->db->select('id_termo,conteudo, situacao');
        $this->db->where ("situacao", 1);
        $query = $this->db->get('amn_termo');

        return $query->row_array();
    }
     public function insereClienteTermo($termo) {
        
        $this->db->insert('amnn_termo', $termo);
    }
    public function obtemClienteTermo($id_cliente) {
        
        $this->db->select('id_cliente,id_termo');
        $this->db->where ("id_cliente", $id_cliente);
        $this->db->order_by("id", "desc");        
        $query = $this->db->get('amn_cliente_termo');

        return $query->row_array();
    }
    public function obtemCliente() {
        
        $this->db->select('id_negocio, nome, email, saldo, bonificacao, cpf, ddd_celular, celular, data_cadastro, endereco, numero, complemento, cep, bairro, cidade, estado, situacao');
        $query = $this->db->get('amn_cliente');

        return $query->row_array();
    }
    
    public function obtemClienteCPF($cpf) {
        
        $this->db->select('id_negocio, nome, email, saldo, bonificacao, cpf, ddd_celular, celular, data_cadastro, endereco, numero, complemento, cep, bairro, cidade, estado, situacao');
        $this->db->where('cpf', $cpf);
        $query = $this->db->get('amn_cliente');

        return $query->row_array();
    }
   
     public function insereCliente($data, $id) {

        date_default_timezone_set('America/Belem');
        $tempo = date('Y-m-d H:i:s', time());
        
        $this->db->insert('amn_cliente', $data);
        $id_cliente = $this->db->insert_id(); 
        
        $dados = array (
        'id_cliente' => $id_cliente,
        'id_aluno' => $_SESSION['logado']['id'],
        'instituicao' => 1,
        'situacao' => 1    
        );
        
        $this->db->insert('amn_aluno', $dados);
        
        $termo = array('id_termo' => $id, 'id_cliente' => $id_cliente, 'data'=> $tempo);
        $this->db->insert('amn_cliente_termo', $termo);
    }
    
    public function atualizaClienteTermo($dados) {
        
       $this->db->insert('amn_cliente_termo', $dados);

    }
    
    public function verificainstituicao($chave) {
        
        $this->db->select('id_instituicao,nome, chave, token, situacao');
        $this->db->where ('chave', $chave);
        $this->db->where ('situacao', 1);
        $query = $this->db->get('amn_instituicao')->row_array();

        return $query;
    }
}
