<?php

defined('BASEPATH') OR exit('No direct script access allowed');

class Saldo extends CI_Controller {

    function __construct() {
        parent::__construct();
        $this->load->model('Cadastro_Model');
        $this->load->model('Saldo_Model');
        $this->load->model('Transferencia_Model');
        $this->load->library('criptografia');
        $this->load->database();
        $this->ci = & get_instance();
        $this->ci->load->config('url', TRUE);
    }

    public function saldo() {
        $aluno = $this->Cadastro_Model->verificaAluno();
        $cliente = $this->Saldo_Model->clienteNegocio();
        $id_negocio = $cliente['id_negocio'];
        $id_cliente = $cliente['id_cliente'];
        $this->session->set_userdata("id_cliente", $id_cliente);
        $this->session->set_userdata("id_negocio", $id_negocio);

        $cliente_termo = $this->Cadastro_Model->obtemClienteTermo($id_cliente);
        $termo_antigo = $cliente_termo['id_termo']; //TERMO DE USO QUE USUARIO ACEITOU
        $termos = $this->Cadastro_Model->obtemTermo(); //TERMO DE USO EM USO NO MOMENTO
        $termo_novo = $termos['id_termo'];

        if (isset($_SESSION['logado']) == TRUE && $aluno != NULL) {
            if (($termo_novo) != $termo_antigo) {
                $this->session->set_flashdata('novo-termo', '<div class="alert alert-warning" role="alert"><span class="glyphicon glyphicon-exclamation-sign login-span"></span> Temos um novo termo de uso. Confira as mudanças </div>');
                redirect('novotermo');
            }
            $dados = array('transacao_efetuada' => $this->Transferencia_Model->verificaTransferenciaCliente(),'saldos' => $this->Saldo_Model->saldo($id_negocio), 'cliente' => $this->Cadastro_Model->verificaAluno());
            $this->load->view('saldo', $dados);
        } else {
            redirect('base');
        }
    }

    public function adicionarsaldo() {

        $aluno = $this->Cadastro_Model->verificaAluno();

        if (isset($_SESSION['logado']) == TRUE && $aluno != NULL) {
            $dados = array('saldos' => $this->Saldo_Model->saldo(), 'cliente' => $this->Cadastro_Model->verificaAluno());
            $this->load->view('adicionarsaldo', $dados);
        } else {
            redirect('base');
        }
    }

    public function atualizatermo() {

        $cliente = $this->Saldo_Model->clienteNegocio();
        $id_cliente = $cliente['id_cliente'];

        $dados = array('id_cliente' => $id_cliente, 'id_termo' => $this->input->post('termo'), 'data' => date('Y-m-d H:i:s'));
        $this->Cadastro_Model->atualizaClienteTermo($dados);

        $termos = $this->Cadastro_Model->obtemTermo(); //TERMO DE USO EM USO NO MOMENTO
        $termo_novo = $termos['id_termo'];

        $cliente_termo = $this->Cadastro_Model->obtemClienteTermo($id_cliente); //TERMO DE USO QUE O USUARIO SE CADASTROU
        $termo_antigo = $cliente_termo['id_termo']; //TERMO DE USO QUE USUARIO ACEITOU

        if (($termo_novo) == $termo_antigo) {

            $this->session->set_flashdata('termo-novo', '<script> swal({position: "top-right",type: "success",title: "Obrigado por aceitar o novo termo de uso", showConfirmButton: false, timer: 3000});</script>');

            redirect('saldo');
        }
    }

}
